==> haskell-tasty-th-0.1.7-658.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-FR3GlKw5pPXFQOoobMlJKd
key:                  tasty-th-0.1.7-FR3GlKw5pPXFQOoobMlJKd
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  e3b6157980d5a4ebd868d610e0cd7da0
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-FR3GlKw5pPXFQOoobMlJKd
depends:
    base-4.18.3.0 haskell-src-exts-1.23.1-3FJzC4LIqYAD0q0bnl8iGb
    tasty-1.5.2-DYWdVUlVmZ2GEsYE1QJgVb template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-658.4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-JiD1boARlUuFKSFnKU1y23
key:                  tasty-th-0.1.7-JiD1boARlUuFKSFnKU1y23
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  08b2aee9418dafae3dfb458a0f6b4fec
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/tasty-th-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-th
hs-libraries:         HStasty-th-0.1.7-JiD1boARlUuFKSFnKU1y23
depends:
    base-4.18.3.0 haskell-src-exts-1.23.1-B0H4hEPY8M8ExexllKZ3We
    tasty-1.5.2-1URN3hwk0ElEsqpxhMRHaT template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
